"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchJwt = void 0;
const request_1 = require("../../common/http/request");
const logger_1 = require("../../logs/logger");
async function fetchJwt(apiHostname, clientId, clientSecret) {
    try {
        const data = {
            grant_type: 'client_credentials',
            client_id: clientId,
            client_secret: clientSecret,
        };
        const formData = new URLSearchParams(data);
        const request = {
            url: `${apiHostname}/oauth2/token`,
            headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
            method: 'POST',
            body: formData.toString(),
        };
        const oauthResponse = await (0, request_1.makeRequestToDownstream)(request);
        if (oauthResponse.statusCode != 200) {
            const errorBody = JSON.parse(oauthResponse.body);
            throw new Error(`${oauthResponse.statusCode}-${errorBody.error}:${errorBody.error_description}`);
        }
        const accessToken = JSON.parse(oauthResponse.body);
        const jwt = accessToken.access_token;
        const type = accessToken.token_type;
        const expiresIn = accessToken.expires_in;
        return { expiresIn: expiresIn, authHeader: `${type} ${jwt}` };
    }
    catch (err) {
        logger_1.log.error({ err }, 'Unable to retrieve JWT');
    }
}
exports.fetchJwt = fetchJwt;
//# sourceMappingURL=oauth.js.map