"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.highAvailabilityModeEnabled = exports.getClientConfigMetadata = void 0;
const logger_1 = require("../../logs/logger");
const getClientConfigMetadata = (clientConfig) => {
    const configMetadata = {
        haMode: highAvailabilityModeEnabled(clientConfig),
        debugMode: clientConfig.logLevel === 'debug' ? true : false,
        bodyLogMode: clientConfig.logEnableBody ? true : false,
        credPooling: isCredPoolingUsed(clientConfig),
        privateCa: clientConfig.nodeExtraCaCert ? true : false,
        tlsReject: parseInt(clientConfig.nodeTlsRejectUnauthorized) === 0 ? true : false,
        proxy: clientConfig.httpProxy || clientConfig.httpsProxy ? true : false,
        customAccept: clientConfig.accept ? true : false,
        insecureDownstream: clientConfig.insecureDownstream ? true : false,
        universalBroker: clientConfig.universalBrokerEnabled ? true : false,
    };
    return configMetadata;
};
exports.getClientConfigMetadata = getClientConfigMetadata;
const isCredPoolingUsed = (config) => {
    for (const key in config) {
        if (config.hasOwnProperty(key) && key.includes('_POOL')) {
            return true; // Found a key containing '_POOL'
        }
    }
    return false;
};
function highAvailabilityModeEnabled(config) {
    // high availability mode is disabled per default
    let highAvailabilityModeEnabled = false;
    const highAvailabilityModeEnabledValue = config
        .BROKER_HA_MODE_ENABLED;
    if (typeof highAvailabilityModeEnabledValue !== 'undefined') {
        highAvailabilityModeEnabled =
            highAvailabilityModeEnabledValue.toLowerCase() === 'true' ||
                highAvailabilityModeEnabledValue.toLowerCase() === 'yes';
    }
    logger_1.log.info({ enabled: highAvailabilityModeEnabled }, 'checking for HA mode');
    return highAvailabilityModeEnabled;
}
exports.highAvailabilityModeEnabled = highAvailabilityModeEnabled;
//# sourceMappingURL=configHelpers.js.map