"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.retrieveConnectionsForDeployment = void 0;
const fs_1 = require("fs");
const request_1 = require("../../common/http/request");
const retrieveConnectionsForDeployment = async (clientOpts, universalFilePath) => {
    var _a, _b;
    try {
        const tenantId = clientOpts.config.tenantId;
        const installId = clientOpts.config.installId;
        const deploymentId = clientOpts.config.deploymentId;
        const apiVersion = clientOpts.config.apiVersion;
        const request = {
            url: `${clientOpts.config.API_BASE_URL}/rest/tenants/${tenantId}/brokers/installs/${installId}/deployments/${deploymentId}/connections?version=${apiVersion}`,
            headers: {
                'Content-Type': 'application/vnd.api+json',
                Authorization: `${(_a = clientOpts.accessToken) === null || _a === void 0 ? void 0 : _a.authHeader}`,
            },
            method: 'GET',
        };
        const connectionsResponse = await (0, request_1.makeRequestToDownstream)(request);
        if (connectionsResponse.statusCode != 200) {
            const errorBody = JSON.parse(connectionsResponse.body);
            throw new Error(`${connectionsResponse.statusCode}-${errorBody.error}:${errorBody.error_description}`);
        }
        const connections = JSON.parse(connectionsResponse.body)
            .data;
        const connectionsObjectForFile = { CONNECTIONS: {} };
        for (let i = 0; i < connections.length; i++) {
            connectionsObjectForFile.CONNECTIONS[`${connections[i].attributes.name}`] = {
                ...connections[i].attributes.configuration.default,
                ...connections[i].attributes.configuration.required,
            };
            connectionsObjectForFile.CONNECTIONS[`${connections[i].attributes.name}`].type = connections[i].attributes.type;
            connectionsObjectForFile.CONNECTIONS[`${connections[i].attributes.name}`].identifier = connections[i].id;
        }
        const universalConfigFileBuffer = (0, fs_1.readFileSync)(universalFilePath);
        const universalConfigFile = JSON.parse((_b = universalConfigFileBuffer.toString()) !== null && _b !== void 0 ? _b : { CONNECTIONS: {} });
        universalConfigFile['CONNECTIONS'] = connectionsObjectForFile.CONNECTIONS;
        (0, fs_1.writeFileSync)(universalFilePath, JSON.stringify(universalConfigFile));
        return;
    }
    catch (err) {
        throw new Error(`${err} - Error retrieving and loading connections from Deployment ID`);
    }
};
exports.retrieveConnectionsForDeployment = retrieveConnectionsForDeployment;
//# sourceMappingURL=remoteConfig.js.map