"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.websocketConnectionSelectorMiddleware = void 0;
const logger_1 = require("../../logs/logger");
const config_1 = require("../../common/config/config");
const socketHelpers_1 = require("../utils/socketHelpers");
const websocketConnectionSelectorMiddleware = (req, res, next) => {
    const config = (0, config_1.getConfig)();
    if (!config.universalBrokerEnabled) {
        res.locals.websocket = (0, socketHelpers_1.isWebsocketConnOpen)(res.locals.websocketConnections[0])
            ? res.locals.websocketConnections[0]
            : res.locals.websocketConnections[1];
        next();
    }
    else {
        const websocketConnections = res.locals
            .websocketConnections;
        const availableConnectionsTypes = websocketConnections.map((x) => x.supportedIntegrationType);
        let inboundRequestType = '';
        // 2 cases: webhooks/TYPE, /v[1-2] Container registry.
        if (req.path.startsWith('/webhook')) {
            const splitUrl = req.path.split('/');
            if (splitUrl.length > 2 &&
                availableConnectionsTypes.includes(splitUrl[2])) {
                inboundRequestType = req.path.split('/')[2];
            }
            else if (splitUrl.length > 2 &&
                splitUrl[2] == 'github' &&
                availableConnectionsTypes.includes('github-enterprise')) {
                inboundRequestType = 'github-enterprise';
            }
            else {
                logger_1.log.warn({ url: req.path }, 'Unexpected type in webhook request');
                res
                    .status(401)
                    .send('Unexpected type in webhook request, unable to forward to server.');
                return;
            }
        }
        else if (req.path.startsWith('/api/v1/') ||
            req.path.startsWith('/api/v2/') ||
            req.path.startsWith('/v1/') ||
            req.path.startsWith('/v2/')) {
            inboundRequestType = 'container-registry-agent';
        }
        else {
            logger_1.log.error({ url: req.path }, 'Unknown type in client->server request.');
            if (config.serviceEnv == 'universaltest') {
                // only to support testing, blocking all other unknown request types
                inboundRequestType =
                    websocketConnections.length > 0
                        ? websocketConnections[0].supportedIntegrationType
                        : '';
            }
            else {
                res
                    .status(401)
                    .send('Unknown request type, unable to forward to server.');
                return;
            }
        }
        const selectedWebsocketConnection = websocketConnections.find((conn) => conn.supportedIntegrationType == inboundRequestType);
        res.locals.websocket = selectedWebsocketConnection;
        next();
    }
};
exports.websocketConnectionSelectorMiddleware = websocketConnectionSelectorMiddleware;
//# sourceMappingURL=websocketConnectionMiddlewares.js.map