"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.bindSocketToWebserver = exports.getSocketConnections = void 0;
const primus_1 = __importDefault(require("primus"));
const primus_emitter_1 = __importDefault(require("primus-emitter"));
const errorHandler_1 = require("./socketHandlers/errorHandler");
const connectionHandler_1 = require("./socketHandlers/connectionHandler");
const initHandlers_1 = require("./socketHandlers/initHandlers");
const token_1 = require("../common/utils/token");
const logger_1 = require("../logs/logger");
const socketConnections = new Map();
const getSocketConnections = () => {
    return socketConnections;
};
exports.getSocketConnections = getSocketConnections;
const socket = ({ server, loadedServerOpts }) => {
    const ioConfig = {
        transformer: 'engine.io',
        parser: 'EJSON',
        maxLength: parseInt(loadedServerOpts.config.socketMaxResponseLength) || 22020096,
        transport: {
            allowEIO3: true,
            pingInterval: parseInt(loadedServerOpts.config.socketPingInterval) || 25000,
            pingTimeout: parseInt(loadedServerOpts.config.socketPingTimeout) || 20000,
        },
        compression: Boolean(loadedServerOpts.config.socketUseCompression) || false,
    };
    const websocket = new primus_1.default(server, ioConfig);
    websocket.authorize(async (req, done) => {
        const maskedToken = (0, token_1.maskToken)(req.uri.pathname.replaceAll(/^\/primus\/([^/]+)\//g, '$1').toLowerCase());
        const authHeader = req.headers['authorization'];
        if ((!authHeader || !authHeader.startsWith('Bearer')) &&
            loadedServerOpts.config.BROKER_SERVER_MANDATORY_AUTH_ENABLED) {
            logger_1.log.error({ maskedToken }, 'request missing Authorization header');
            done({
                statusCode: 401,
                authenticate: 'Bearer',
                message: 'missing required authorization header',
            });
            return;
        }
        const jwt = authHeader
            ? authHeader.substring(authHeader.indexOf(' ') + 1)
            : '';
        if (!jwt)
            logger_1.log.debug({}, `TODO: Validate jwt`);
        done();
        // let oauthResponse = await axiosInstance.request({
        //   url: 'http://localhost:8080/oauth2/introspect',
        //   method: 'POST',
        //   headers: {
        //     'Content-Type': 'application/x-www-form-urlencoded',
        //   },
        //   auth: {
        //     username: 'broker-connection-a',
        //     password: 'secret',
        //   },
        //   data: `token=${token}`,
        // });
        // if (!oauthResponse.data.active) {
        //   logger.error({maskedToken}, 'JWT is not active (could be expired, malformed, not issued by us, etc)');
        //   done({
        //     statusCode: 403,
        //     message: 'token not active',
        //   });
        // } else {
        //   req.oauth_data = oauthResponse.data;
        //   done();
        // }
    });
    websocket.socketType = 'server';
    websocket.socketVersion = 1;
    websocket.plugin('emitter', primus_emitter_1.default);
    (0, initHandlers_1.initConnectionHandler)(loadedServerOpts, websocket);
    websocket.on('error', errorHandler_1.handleIoError);
    websocket.on('connection', connectionHandler_1.handleSocketConnection);
    return { websocket };
};
const bindSocketToWebserver = (server, loadedServerOpts) => {
    // bind the socket server to the web server
    return socket({
        server,
        loadedServerOpts,
    });
};
exports.bindSocketToWebserver = bindSocketToWebserver;
//# sourceMappingURL=socket.js.map